@@ -1,8 +1,8 @@
 readSDML <- function(file = "", text = NULL, validate = FALSE,
-                     read.description = FALSE)
+                     read.description = FALSE, ...)
 {
   tree <- xmlTreeParse(file=file, asText=!is.null(text), validate=validate,
-                       handler=handlersSDML(), asTree=TRUE)
+                       handler=handlersSDML(), asTree=TRUE, ...)
 
   ## is this file a StatDataML file ?    
   if (xmlName(xmlRoot(tree)) != "StatDataML")
